@@ -79,14 +79,14 @@ def run_appengine_server(app):
     return action
 
 def run_gunicorn_server(app):
-    def action(host=('h','127.0.0.1'),port=('p', 8000),workers=('w',4)):
+    def action(bind=('b','127.0.0.1:8000'),workers=('w',4),pid=('p','tmp/flask.pid')):
         """run application use gunicorn http server
         """
         from gunicorn import version_info
         if version_info < (0, 9, 0):
             from gunicorn.arbiter import Arbiter
             from gunicorn.config import Config
-            arbiter = Arbiter(Config({'bind': "%s:%d" % (host, int(port)),'workers': 4}), app)
+            arbiter = Arbiter(Config({'bind':bind,'workers': 4}), app)
             arbiter.run()
         else:
             from gunicorn.app.base import Application
@@ -94,8 +94,9 @@ def run_gunicorn_server(app):
             class FlaskApplication(Application):
                 def init(self, parser, opts, args):
                     return {
-                        'bind': '{0}:{1}'.format(host, port),
-                        'workers': 4
+                        'bind': bind,
+                        'workers': workers,
+                        'pidfile':pid,
                     }
                 
                 def load(self):
